@@ -2,8 +2,10 @@
 
 ###############################################################################
 #
-# This example demonstrates writing cell comments. A cell comment is indicated
-# in Excel by a small red triangle in the upper right-hand corner of the cell.
+# This example demonstrates writing cell comments.
+#
+# A cell comment is indicated in Excel by a small red triangle in the upper
+# right-hand corner of the cell.
 #
 # For more advanced comment options see comments2.pl.
 #
@@ -20,3 +22,5 @@ my $worksheet = $workbook->add_worksheet();
 
 $worksheet->write        ('A1', 'Hello'            );
 $worksheet->write_comment('A1', 'This is a comment');
+
+__END__
